@@ -54,6 +54,7 @@ __all__ = (
     "ComputeEnvironmentOrderTypeDef",
     "Ec2ConfigurationTypeDef",
     "LaunchTemplateSpecificationTypeDef",
+    "EphemeralStorageTypeDef",
     "FargatePlatformConfigurationTypeDef",
     "KeyValuePairTypeDef",
     "MountPointTypeDef",
@@ -82,6 +83,7 @@ __all__ = (
     "EksContainerVolumeMountTypeDef",
     "EksEmptyDirTypeDef",
     "EksHostPathTypeDef",
+    "EksMetadataTypeDef",
     "EksSecretTypeDef",
     "EvaluateOnExitTypeDef",
     "ShareAttributesTypeDef",
@@ -263,6 +265,13 @@ LaunchTemplateSpecificationTypeDef = TypedDict(
     total=False,
 )
 
+EphemeralStorageTypeDef = TypedDict(
+    "EphemeralStorageTypeDef",
+    {
+        "sizeInGiB": int,
+    },
+)
+
 FargatePlatformConfigurationTypeDef = TypedDict(
     "FargatePlatformConfigurationTypeDef",
     {
@@ -534,6 +543,14 @@ EksHostPathTypeDef = TypedDict(
     total=False,
 )
 
+EksMetadataTypeDef = TypedDict(
+    "EksMetadataTypeDef",
+    {
+        "labels": Dict[str, str],
+    },
+    total=False,
+)
+
 _RequiredEksSecretTypeDef = TypedDict(
     "_RequiredEksSecretTypeDef",
     {
@@ -1356,6 +1373,7 @@ EksPodPropertiesOverrideTypeDef = TypedDict(
     "EksPodPropertiesOverrideTypeDef",
     {
         "containers": Sequence[EksContainerOverrideTypeDef],
+        "metadata": EksMetadataTypeDef,
     },
     total=False,
 )
@@ -1370,6 +1388,7 @@ EksPodPropertiesDetailTypeDef = TypedDict(
         "volumes": List[EksVolumeTypeDef],
         "podName": str,
         "nodeName": str,
+        "metadata": EksMetadataTypeDef,
     },
     total=False,
 )
@@ -1382,6 +1401,7 @@ EksPodPropertiesTypeDef = TypedDict(
         "dnsPolicy": str,
         "containers": List[EksContainerTypeDef],
         "volumes": List[EksVolumeTypeDef],
+        "metadata": EksMetadataTypeDef,
     },
     total=False,
 )
@@ -1510,6 +1530,7 @@ ContainerDetailTypeDef = TypedDict(
         "secrets": List[SecretTypeDef],
         "networkConfiguration": NetworkConfigurationTypeDef,
         "fargatePlatformConfiguration": FargatePlatformConfigurationTypeDef,
+        "ephemeralStorage": EphemeralStorageTypeDef,
     },
     total=False,
 )
@@ -1537,6 +1558,7 @@ ContainerPropertiesTypeDef = TypedDict(
         "secrets": List[SecretTypeDef],
         "networkConfiguration": NetworkConfigurationTypeDef,
         "fargatePlatformConfiguration": FargatePlatformConfigurationTypeDef,
+        "ephemeralStorage": EphemeralStorageTypeDef,
     },
     total=False,
 )
